@@ -8,10 +8,10 @@
 #'library(daltoolbox)
 #'
 #'#loading the example database
-#'data(examples_anomalies)
+#'data(examples_motifs)
 #'
 #'#Using sequence example
-#'dataset <- examples_anomalies$sequence
+#'dataset <- examples_motifs$simple
 #'head(dataset)
 #'
 #'# setting up motif discovery method
@@ -27,7 +27,7 @@
 #'print(detection[(detection$event),])
 #'
 #'@export
-hmo_sax <- function(a, w, qtd) {
+hmo_sax <- function(a, w, qtd=2) {
   obj <- harbinger()
   if(!(is.numeric(a)&&(a>=1)&&(a<=26))) stop("alphabet must be between 1 and 26", call. = FALSE)
   obj$a <- a
@@ -37,6 +37,19 @@ hmo_sax <- function(a, w, qtd) {
   return(obj)
 }
 
+comp_word_entropy <- function(str) {
+  x <- strsplit(str, "^")
+  x <- x[[1]]
+  n <- length(x)
+  x <- table(x)
+  x <- x / n
+  y <- 0
+  for (i in 1:length(x)) {
+    y <- y - x[i]*log(x[i],2)
+    
+  }
+  return(y)
+}
 
 #'@importFrom stats na.omit
 #'@importFrom stringr str_length
@@ -52,56 +65,58 @@ detect.hmo_sax <- function(obj, serie, ...) {
   i <- 0
   total_count <- 0
   if(is.null(serie)) stop("No data was provided for computation", call. = FALSE)
-
+  falsemotifs <- round(obj$w/2)
+  
   obj <- obj$har_store_refs(obj, serie)
-
+  
   tsax <- trans_sax(obj$a)
   tsax <- fit(tsax, obj$serie)
   tss <- transform(tsax, obj$serie)
-
+  
   tsw <- daltoolbox::ts_data(tss, obj$w)
   seq <- base::apply(tsw, MARGIN = 1, function(x) paste(as.vector(x), collapse=""))
-  data <- data.frame(i = 1:nrow(tsw), seq)
-  result <- data |> dplyr::group_by(seq) |> dplyr::summarise(total_count=dplyr::n())
+  entropy <- base::apply(as.matrix(seq), MARGIN = 1, comp_word_entropy)
+  
+  data <- data.frame(i = 1:nrow(tsw), seq, entropy)
+  
+  result <- data |> dplyr::group_by(seq) |> dplyr::summarise(total_count=dplyr::n(), entropy=mean(entropy))
   result <- result[result$total_count >= obj$qtd,]
-  result <- result |> dplyr::arrange(dplyr::desc(total_count)) |> dplyr::select(seq)
-  result <- result$seq
-  data <- data[data$seq %in% result,]
-
+  result <- result |> dplyr::arrange(dplyr::desc(total_count), dplyr::desc(entropy)) 
+  data <- data[data$seq %in% result$seq,]
+  
   motifs <- NULL
-  for (j in 1:length(result)) {
-    motif <- data[data$seq == result[j],]
-    pos <- NULL
-    for (k in 1:obj$w) {
-      pos <- c(pos, motif$i + (k - 1))
-    }
-    data <- data[!(data$i %in% pos),]
-
+  for (j in 1:nrow(result)) {
+    motif <- data[data$seq == result$seq[j],]
     if (nrow(motif) > 0) {
-      vec <- motif$i
-      svec <- base::split(vec, base::cumsum(c(1, diff(vec) != 1)))
+      refs <- motif$i
+      svec <- base::split(refs, base::cumsum(c(1, diff(refs) != 1)))
       vec <- base::sapply(svec, min)
-
+      
       motif <- motif[(motif$i %in% vec),]
-
       if (length(vec) >= obj$qtd) {
         motifs <- base::rbind(motifs, motif)
+        
+        pos <- NULL
+        for (k in (-falsemotifs):falsemotifs) {
+          pos <- c(pos, refs + k)
+        }
+        data <- data[!(data$i %in% pos),]
       }
     }
   }
-
+  
   mots <- rep(FALSE, length(obj$serie))
   seqs <- rep(NA, length(obj$serie))
   mots[motifs$i] <- TRUE
   seqs[motifs$i] <- motifs$seq
-
+  
   detection <- obj$har_restore_refs(obj, anomalies = mots)
   detection$seq <- NA
   detection$seqlen <- NA
   detection$type[detection$type=="anomaly"] <- "motif"
   detection$seq[obj$non_na] <- seqs
   detection$seqlen[obj$non_na] <- obj$w
-
+  
   return(detection)
 }
 
